@@ -1,12 +1,7 @@
-import logging
-from pathlib import Path
-from typing import Any, Callable, Dict, Iterable, Optional, Union
+from typing import Callable, Dict, Iterable, Optional, Union
 
-from kedro.extras.datasets.pickle import PickleDataSet
-from kedro.io import DataCatalog, MemoryDataSet
 from kedro.pipeline import Pipeline
 from kedro.pipeline.node import Node
-from mlflow.models import ModelSignature
 
 MSG_NOT_IMPLEMENTED = (
     "This method is not implemented because it does"
@@ -36,6 +31,9 @@ class PipelineML(Pipeline):
 
     """
 
+    KPM_KWARGS_DEFAULT = {}
+    LOG_MODEL_KWARGS_DEFAULT = {"signature": "auto", "artifact_path": "model"}
+
     def __init__(
         self,
         nodes: Iterable[Union[Node, Pipeline]],
@@ -43,10 +41,8 @@ class PipelineML(Pipeline):
         tags: Optional[Union[str, Iterable[str]]] = None,
         inference: Pipeline,
         input_name: str,
-        conda_env: Optional[Union[str, Path, Dict[str, Any]]] = None,
-        model_name: Optional[str] = "model",
-        model_signature: Union[ModelSignature, str, None] = "auto",
-        **kwargs,
+        kpm_kwargs: Optional[Dict[str, str]] = None,
+        log_model_kwargs: Optional[Dict[str, str]] = None,
     ):
 
         """Store all necessary information for calling mlflow.log_model in the pipeline.
@@ -64,52 +60,37 @@ class PipelineML(Pipeline):
             input_name (str, optional): The name of the dataset in
                 the catalog.yml which the model's user must provide
                 for prediction (i.e. the data). Defaults to None.
-            conda_env (Union[str, Path, Dict[str, Any]], optional):
-                The minimal conda environment necessary for the
-                inference `Pipeline`. It can be either :
-                    - a path to a "requirements.txt": In this case
-                        the packages are parsed and a conda env with
-                        your current python_version and these
-                        dependencies is returned.
-                    - a path to an "environment.yml" : the file is
-                        uploaded "as is".
-                    - a Dict : used as the environment
-                    - None: a base conda environment with your
-                        current python version and your project
-                        version at training time.
-                Defaults to None.
-            model_name (Union[str, None], optional): The name of
-                the folder where the model will be stored in
-                remote mlflow. Defaults to "model".
-            model_signature (Union[ModelSignature, bool]): The mlflow
-             signature of the input dataframe common to training
-             and inference.
-                   - If 'auto', it is infered automatically
-                   - If None, no signature is used
-                   - if a `ModelSignature` instance, passed
-                   to the underlying dataframe
-            kwargs:
+            kpm_kwargs:
                 extra arguments to be passed to `KedroPipelineModel`
                 when the PipelineML object is automatically saved at the end of a run.
                 This includes:
                     - `copy_mode`: the copy_mode to be used for underlying dataset
                     when loaded in memory
                     - `runner`: the kedro runner to run the model with
+            log_model_kwargs:
+                extra arguments to be passed to `mlflow.pyfunc.log_model`
+                - "signature" accepts an extra "auto" which automatically infer the signature
+                based on "input_name" dataset
+
         """
 
         super().__init__(nodes, *args, tags=tags)
 
         self.inference = inference
-        self.conda_env = conda_env
-        self.model_name = model_name
         self.input_name = input_name
-        self.model_signature = model_signature
-        self.kwargs = kwargs  # its purpose is to be eventually reused when saving the model within a hook
-        self._check_consistency()
+        # they will be passed to KedroPipelineModel to enable flexibility
 
-    @property
-    def _logger(self) -> logging.Logger:
-        return logging.getLogger(__name__)
+        kpm_kwargs_with_default = self.KPM_KWARGS_DEFAULT.copy()
+        kpm_kwargs = kpm_kwargs or {}
+        kpm_kwargs_with_default.update(kpm_kwargs)
+        self.kpm_kwargs = kpm_kwargs_with_default
+
+        log_model_kwargs_with_default = self.LOG_MODEL_KWARGS_DEFAULT.copy()
+        log_model_kwargs = log_model_kwargs or {}
+        log_model_kwargs_with_default.update(log_model_kwargs)
+        self.log_model_kwargs = log_model_kwargs_with_default
+
+        self._check_consistency()
 
     @property
     def training(self) -> Pipeline:
@@ -133,7 +114,7 @@ class PipelineML(Pipeline):
         allowed_names = self.inference.inputs()
         pp_allowed_names = "\n    - ".join(allowed_names)
         if name not in allowed_names:
-            raise KedroMlflowPipelineMLInputsError(
+            raise KedroMlflowPipelineMLError(
                 (
                     f"input_name='{name}' but it must be an input of 'inference'"
                     f", i.e. one of: \n    - {pp_allowed_names}"
@@ -141,25 +122,11 @@ class PipelineML(Pipeline):
             )
         self._input_name = name
 
-    @property
-    def model_signature(self) -> str:
-        return self._model_signature
-
-    @model_signature.setter
-    def model_signature(self, model_signature: ModelSignature) -> None:
-        if model_signature is not None:
-            if not isinstance(model_signature, ModelSignature):
-                if model_signature != "auto":
-                    raise ValueError(
-                        f"model_signature must be one of 'None', 'auto', or a 'ModelSignature' Object, got '{type(model_signature)}'"
-                    )
-        self._model_signature = model_signature
-
     def _check_inference(self, inference: Pipeline) -> None:
         nb_outputs = len(inference.outputs())
         outputs_txt = "\n - ".join(inference.outputs())
         if len(inference.outputs()) != 1:
-            raise KedroMlflowPipelineMLOutputsError(
+            raise KedroMlflowPipelineMLError(
                 (
                     "The inference pipeline must have one"
                     " and only one output. You are trying"
@@ -169,76 +136,6 @@ class PipelineML(Pipeline):
                 )
             )
 
-    def _extract_pipeline_catalog(self, catalog: DataCatalog) -> DataCatalog:
-
-        # check that the pipeline is consistent in case its attributes have been
-        # modified manually
-        self._check_consistency()
-
-        sub_catalog = DataCatalog()
-        for data_set_name in self.inference.inputs():
-            if data_set_name == self.input_name:
-                # there is no obligation that this dataset is persisted
-                # thus it is allowed to be an empty memory dataset
-                data_set = catalog._data_sets.get(data_set_name) or MemoryDataSet()
-                sub_catalog.add(data_set_name=data_set_name, data_set=data_set)
-            else:
-                try:
-                    data_set = catalog._data_sets[data_set_name]
-                    if isinstance(
-                        data_set, MemoryDataSet
-                    ) and not data_set_name.startswith("params:"):
-                        raise KedroMlflowPipelineMLDatasetsError(
-                            """
-                                The datasets of the training pipeline must be persisted locally
-                                to be used by the inference pipeline. You must enforce them as
-                                non 'MemoryDataSet' in the 'catalog.yml'.
-                                Dataset '{data_set_name}' is not persisted currently.
-                                """.format(
-                                data_set_name=data_set_name
-                            )
-                        )
-                    self._logger.info(
-                        f"The data_set '{data_set_name}' is added to the PipelineML catalog."
-                    )
-                    sub_catalog.add(data_set_name=data_set_name, data_set=data_set)
-                except KeyError:
-                    raise KedroMlflowPipelineMLDatasetsError(
-                        """
-                                The provided catalog must contains '{data_set_name}' data_set
-                                since it is an input for inference pipeline.
-                                """.format(
-                            data_set_name=data_set_name
-                        )
-                    )
-
-        return sub_catalog
-
-    def extract_pipeline_artifacts(self, catalog: DataCatalog, temp_folder: Path):
-        pipeline_catalog = self._extract_pipeline_catalog(catalog)
-
-        artifacts = {}
-        for name, dataset in pipeline_catalog._data_sets.items():
-            if name != self.input_name:
-                if name.startswith("params:"):
-                    # we need to persist it locally for mlflow access
-                    absolute_param_path = temp_folder / f"params_{name[7:]}.pkl"
-                    persisted_dataset = PickleDataSet(
-                        filepath=absolute_param_path.as_posix()
-                    )
-                    persisted_dataset.save(dataset.load())
-                    artifact_path = absolute_param_path.as_uri()
-                else:
-                    # In this second case, we know it cannot be a MemoryDataSet
-                    # weird bug when directly converting PurePosixPath to windows: it is considered as relative
-                    artifact_path = (
-                        Path(dataset._filepath.as_posix()).resolve().as_uri()
-                    )
-
-                artifacts[name] = artifact_path
-
-        return artifacts
-
     def _check_consistency(self) -> None:
 
         inference_parameters = {
@@ -255,7 +152,7 @@ class PipelineML(Pipeline):
 
         if len(free_inputs_set) > 0:
             input_set_txt = "\n     - ".join(free_inputs_set)
-            raise KedroMlflowPipelineMLInputsError(
+            raise KedroMlflowPipelineMLError(
                 (
                     "The following inputs are free for the inference pipeline:\n"
                     f"    - {input_set_txt}."
@@ -332,13 +229,5 @@ class PipelineML(Pipeline):
         raise NotImplementedError(MSG_NOT_IMPLEMENTED)
 
 
-class KedroMlflowPipelineMLInputsError(Exception):
-    """Error raised when the inputs of KedroPipelineModel are invalid"""
-
-
-class KedroMlflowPipelineMLDatasetsError(Exception):
-    """Error raised when the inputs of KedroPipelineMoel are invalid"""
-
-
-class KedroMlflowPipelineMLOutputsError(Exception):
-    """Error raised when the outputs of KedroPipelineModel are invalid"""
+class KedroMlflowPipelineMLError(Exception):
+    """Error raised when the KedroPipelineModel construction fails"""
