@@ -22,7 +22,6 @@ from mlflow.tracking import MlflowClient
 from kedro_mlflow.config import get_mlflow_config
 from kedro_mlflow.framework.hooks.pipeline_hook import (
     MlflowPipelineHook,
-    _format_conda_env,
     _generate_kedro_command,
 )
 from kedro_mlflow.io.metrics import (
@@ -178,39 +177,6 @@ def mock_failing_pipelines(mocker):
     )
 
 
-@pytest.mark.parametrize(
-    "conda_env,expected",
-    (
-        [None, pytest.lazy_fixture("env_from_none")],
-        [pytest.lazy_fixture("env_from_dict"), pytest.lazy_fixture("env_from_dict")],
-        [
-            pytest.lazy_fixture("requirements_path"),
-            pytest.lazy_fixture("env_from_requirements"),
-        ],
-        [
-            pytest.lazy_fixture("requirements_path_str"),
-            pytest.lazy_fixture("env_from_requirements"),
-        ],
-        [
-            pytest.lazy_fixture("environment_path"),
-            pytest.lazy_fixture("env_from_environment"),
-        ],
-        [
-            pytest.lazy_fixture("environment_path_str"),
-            pytest.lazy_fixture("env_from_environment"),
-        ],
-    ),
-)
-def test_format_conda_env(conda_env, expected):
-    conda_env = _format_conda_env(conda_env)
-    assert conda_env == expected
-
-
-def test_format_conda_env_error():
-    with pytest.raises(ValueError, match="Invalid conda_env"):
-        _format_conda_env(["invalid_list"])
-
-
 @pytest.fixture
 def dummy_pipeline():
     def preprocess_fun(data):
@@ -299,8 +265,7 @@ def dummy_pipeline_ml(dummy_pipeline, env_from_dict):
         training=dummy_pipeline.only_nodes_with_tags("training"),
         inference=dummy_pipeline.only_nodes_with_tags("inference"),
         input_name="raw_data",
-        conda_env=env_from_dict,
-        model_name="model",
+        log_model_kwargs={"conda_env": env_from_dict, "artifact_path": "model"},
     )
     return dummy_pipeline_ml
 
@@ -374,7 +339,9 @@ def pipeline_ml_with_parameters():
         training=full_pipeline.only_nodes_with_tags("training"),
         inference=full_pipeline.only_nodes_with_tags("inference"),
         input_name="data",
-        conda_env={"python": "3.7.0", "dependencies": ["kedro==0.16.5"]},
+        log_model_kwargs={
+            "conda_env": {"python": "3.7.0", "dependencies": ["kedro==0.16.5"]},
+        },
     )
     return pipeline_ml_with_parameters
 
@@ -446,7 +413,7 @@ def test_mlflow_pipeline_hook_with_different_pipeline_types(
         )
         # test : parameters should have been logged
         mlflow_conf = get_mlflow_config()
-        mlflow_client = MlflowClient(mlflow_conf.mlflow_tracking_uri)
+        mlflow_client = MlflowClient(mlflow_conf.server.mlflow_tracking_uri)
         run_data = mlflow_client.get_run(run_id).data
 
         # all run_params are recorded as tags
@@ -517,9 +484,13 @@ def test_mlflow_pipeline_hook_with_copy_mode(
             training=dummy_pipeline_ml.training,
             inference=dummy_pipeline_ml.inference,
             input_name=dummy_pipeline_ml.input_name,
-            conda_env={"python": "3.7.0", "dependencies": ["kedro==0.16.5"]},
-            model_name=dummy_pipeline_ml.model_name,
-            copy_mode=copy_mode,
+            log_model_kwargs={
+                "artifact_path": dummy_pipeline_ml.log_model_kwargs["artifact_path"],
+                "conda_env": {"python": "3.7.0", "dependencies": ["kedro==0.16.5"]},
+            },
+            kpm_kwargs={
+                "copy_mode": copy_mode,
+            },
         )
         pipeline_hook.before_pipeline_run(
             run_params=dummy_run_params, pipeline=pipeline_to_run, catalog=dummy_catalog
@@ -551,7 +522,7 @@ def test_mlflow_pipeline_hook_metric_metrics_with_run_id(
     with KedroSession.create(project_path=kedro_project_with_mlflow_conf):
 
         mlflow_conf = get_mlflow_config()
-        mlflow.set_tracking_uri(mlflow_conf.mlflow_tracking_uri)
+        mlflow.set_tracking_uri(mlflow_conf.server.mlflow_tracking_uri)
 
         with mlflow.start_run():
             existing_run_id = mlflow.active_run().info.run_id
@@ -608,7 +579,7 @@ def test_mlflow_pipeline_hook_metric_metrics_with_run_id(
             catalog=dummy_catalog_with_run_id,
         )
 
-        mlflow_client = MlflowClient(mlflow_conf.mlflow_tracking_uri)
+        mlflow_client = MlflowClient(mlflow_conf.server.mlflow_tracking_uri)
         # the first run is created in Default (id 0),
         # but the one initialised in before_pipeline_run
         # is create  in kedro_project experiment (id 1)
@@ -650,7 +621,7 @@ def test_mlflow_pipeline_hook_save_pipeline_ml_with_parameters(
     with KedroSession.create(project_path=kedro_project_with_mlflow_conf):
 
         mlflow_conf = get_mlflow_config()
-        mlflow.set_tracking_uri(mlflow_conf.mlflow_tracking_uri)
+        mlflow.set_tracking_uri(mlflow_conf.server.mlflow_tracking_uri)
 
         catalog_with_parameters = DataCatalog(
             {
@@ -736,9 +707,11 @@ def test_mlflow_pipeline_hook_with_pipeline_ml_signature(
             training=dummy_pipeline.only_nodes_with_tags("training"),
             inference=dummy_pipeline.only_nodes_with_tags("inference"),
             input_name="raw_data",
-            conda_env=env_from_dict,
-            model_name="model",
-            model_signature=model_signature,
+            log_model_kwargs={
+                "conda_env": env_from_dict,
+                "artifact_path": "model",
+                "signature": model_signature,
+            },
         )
 
         pipeline_hook.after_catalog_created(
@@ -816,11 +789,16 @@ def test_on_pipeline_error(
 
     bootstrap_project(kedro_project_with_mlflow_conf)
     with KedroSession.create(project_path=kedro_project_with_mlflow_conf) as session:
+        kmc = get_mlflow_config()
         with pytest.raises(ValueError):
             session.run()
 
-        # the run we want is the last one in Default experiment
-        failing_run_info = MlflowClient(tracking_uri).list_run_infos("0")[0]
+        # the run we want is the last one in the configuration experiment
+        mlflow_client = MlflowClient(tracking_uri)
+        experiment = mlflow_client.get_experiment_by_name(kmc.tracking.experiment.name)
+        failing_run_info = MlflowClient(tracking_uri).list_run_infos(
+            experiment.experiment_id
+        )[0]
         assert mlflow.active_run() is None  # the run must have been closed
         assert failing_run_info.status == RunStatus.to_string(
             RunStatus.FAILED
