@@ -1,7 +1,7 @@
 import pytest
 import yaml
 
-from kedro_mlflow.config.kedro_mlflow_config import ExperimentOptions, KedroMlflowConfig
+from kedro_mlflow.config.kedro_mlflow_config import KedroMlflowConfig
 from kedro_mlflow.framework.cli.cli import TEMPLATE_FOLDER_PATH
 from kedro_mlflow.framework.cli.cli_utils import write_jinja_template
 
@@ -10,7 +10,7 @@ from kedro_mlflow.framework.cli.cli_utils import write_jinja_template
 def template_mlflowyml(tmp_path):
     # the goal is to discover all potential ".py" files
     # but for now there is only "run.py"
-    # # this is rather a safeguard for further add
+    # this is rather a safeguard for further add
     raw_template_path = TEMPLATE_FOLDER_PATH / "mlflow.yml"
     rendered_template_path = tmp_path / raw_template_path.name
     tags = {
@@ -33,7 +33,15 @@ def test_mlflow_yml_rendering(template_mlflowyml):
     # and here we do not want to check the path
     expected_config = KedroMlflowConfig.construct(
         project_path="fake/path",
-        experiment=ExperimentOptions(name="fake_project"),  # check for proper rendering
+        tracking=dict(
+            disable_tracking=dict(pipelines=[]),
+            experiment=dict(name="fake_project", restore_if_deleted=True),
+            params=dict(
+                dict_params=dict(flatten=False, recursive=True, sep="."),
+                long_params_strategy="fail",
+            ),
+            run=dict(id=None, name=None, nested=True),
+        ),  # check for proper rendering
     )
 
     assert mlflow_config == expected_config.dict(exclude={"project_path"})
